@@ -6,6 +6,7 @@ from flask import Blueprint
 from flask.ext.babelpkg import gettext as _gettext, lazy_gettext
 from flask.ext.appbuilder.babel.manager import BabelManager
 from flask.ext.appbuilder import translations
+from flask.ext.appbuilder import Base
 from .security.manager import SecurityManager
 from menu import Menu
 
@@ -94,7 +95,8 @@ class BaseApp(object):
 
         # Creating Developer's models
         self.db.create_all()
-
+        engine = self.db.session.get_bind(mapper=None, clause=None)
+        Base.metadata.create_all(engine)
 
     def _init_config_parameters(self):
         if 'APP_NAME' in self.app.config:
@@ -147,7 +149,7 @@ class BaseApp(object):
             for item in category.childs:
                 self._add_permissions_menu(item.name)
 
-    def add_view(self, baseview, name, href="", icon="", category=""):
+    def add_view(self, baseview, name, href="", icon="", label="", category="", category_icon="", category_label=""):
         """
             Add your views associated with menus using this method.
             
@@ -159,16 +161,24 @@ class BaseApp(object):
                 Override the generated href for the menu. if non provided default_view from view will be set as href.
             :param icon:
                 Font-Awesome icon name, optional.
+            :param label:
+                The label that will be displayed on the menu, if absent param name will be used
             :param category:
                 The menu category where the menu will be included, if non provided the view will be acessible as a top menu.
-                
+            :param category_icon:
+                Font-Awesome icon name for the category, optional.
+            
             Examples::
             
                 baseapp = BaseApp(app, db)
-                # Register a view, rendering a top menu without icon
-                baseapp.add_view(MyGeneralView, "My View")
-                # Register a view, a submenu "Other View" from "Other" with a phone icon
-                baseapp.add_view(MyOtherGeneralView, "Other View", icon='fa-phone', category="Others")
+                # Register a view, rendering a top menu without icon.
+                baseapp.add_view(MyGeneralView(), "My View")
+                # Register a view, a submenu "Other View" from "Other" with a phone icon.
+                baseapp.add_view(MyOtherGeneralView(), "Other View", icon='fa-phone', category="Others")
+                $ Regiter a view, with category icon and translation.
+                baseapp.add_view(YetOtherGeneralView(), "Other View", icon='fa-phone',
+                                label=_('Other View'), category="Others", category_icon='fa-envelop',
+                                category_label=_('Other View'))
                 # Add a link
                 baseapp.add_link("google", href="www.google.com", icon = "fa-google-plus")
         """
@@ -179,9 +189,11 @@ class BaseApp(object):
             self._process_ref_related_views()
             self.register_blueprint(baseview)
             self._add_permission(baseview)
-        self.add_link(name=name, href=href, icon=icon, category=category, baseview=baseview)
+        self.add_link(name=name, href=href, icon=icon, label=label,
+                      category=category, category_icon=category_icon,
+                      category_label=category_label, baseview=baseview)
 
-    def add_link(self, name, href, icon="", category="", baseview=None):
+    def add_link(self, name, href, icon="", label="", category="", category_icon="", category_label="", baseview=None):
         """
             Add your own links to menu using this method
             
@@ -191,11 +203,16 @@ class BaseApp(object):
                 Override the generated href for the menu.
             :param icon:
                 Bootstrap included icon name
+            :param label:
+                The label that will be displayed on the menu, if absent param name will be used
             :param category:
-                The menu category where the menu will be included        
+                The menu category where the menu will be included, if non provided the view will be acessible as a top menu.
+            :param category_icon:
+                Font-Awesome icon name for the category, optional.
         """
-        self.menu.add_link(name=name, href=href, icon=icon,
-                           category=category, baseview=baseview)
+        self.menu.add_link(name=name, href=href, icon=icon, label=label,
+                           category=category, category_icon=category_icon,
+                           category_label=category_label, baseview=baseview)
         self._add_permissions_menu(name)
         if category:
             self._add_permissions_menu(category)
