@@ -1,6 +1,7 @@
 import re
 import uuid
 import datetime
+import logging
 
 from sqlalchemy.ext.declarative import declared_attr
 from sqlalchemy import Table, Column, Integer, String, MetaData, ForeignKey, DateTime
@@ -10,14 +11,17 @@ from sqlalchemy.types import String
 from flask import g
 
 
+log = logging.getLogger(__name__)
+
 _camelcase_re = re.compile(r'([A-Z]+)(?=[a-z0-9])')
 
+
 class FileColumn(types.TypeDecorator):
     """
         Extends SQLAlchemy to support and mostly identify a File Column
     """
     impl = types.Text
-    
+
 
 class ImageColumn(types.TypeDecorator):
     """
@@ -26,7 +30,6 @@ class ImageColumn(types.TypeDecorator):
     impl = types.Text
 
 
-
 class BaseMixin(object):
     """
         Use this class has a mixin for your models, it will define your tablenames automatically
@@ -51,8 +54,9 @@ class BaseMixin(object):
             if len(word) > 1:
                 return ('_%s_%s' % (word[:-1], word[-1])).lower()
             return '_' + word.lower()
+
         return _camelcase_re.sub(_join, cls.__name__).lstrip('_')
-            
+
 
 class AuditMixin(BaseMixin):
     """
@@ -67,27 +71,32 @@ class AuditMixin(BaseMixin):
     """
     created_on = Column(DateTime, default=datetime.datetime.now, nullable=False)
     changed_on = Column(DateTime, default=datetime.datetime.now,
-                            onupdate=datetime.datetime.now, nullable=False)
+                        onupdate=datetime.datetime.now, nullable=False)
 
     @declared_attr
     def created_by_fk(cls):
         return Column(Integer, ForeignKey('ab_user.id'),
-                default=cls.get_user_id,nullable=False)
+                      default=cls.get_user_id, nullable=False)
 
     @declared_attr
     def created_by(cls):
-        return relationship("User", primaryjoin='%s.created_by_fk == User.id'%cls.__name__)
+        return relationship("User", primaryjoin='%s.created_by_fk == User.id' % cls.__name__)
 
     @declared_attr
     def changed_by_fk(cls):
         return Column(Integer, ForeignKey('ab_user.id'),
-                default=cls.get_user_id,onupdate=cls.get_user_id,nullable=False)
+                      default=cls.get_user_id, onupdate=cls.get_user_id, nullable=False)
 
     @declared_attr
     def changed_by(cls):
-        return relationship("User", primaryjoin='%s.changed_by_fk == User.id'%cls.__name__)
+        return relationship("User", primaryjoin='%s.changed_by_fk == User.id' % cls.__name__)
 
 
     @classmethod
     def get_user_id(cls):
-        return g.user.id
+        try:
+            log.debug("GET USER ID: {0}".format(g.user.id))
+            return g.user.id
+        except Exception as e:
+            #log.warning("AuditMixin Get User ID {0}".format(str(e)))
+            return None
